"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.video.v1.playlist_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetPlaylistRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_ID_FIELD_NUMBER: builtins.int
    playlist_id: builtins.str
    """ID of the playlist to retrieve."""
    def __init__(
        self,
        *,
        playlist_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["playlist_id", b"playlist_id"]) -> None: ...

global___GetPlaylistRequest = GetPlaylistRequest

@typing.final
class ListPlaylistsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the playlists to list."""
    page_size: builtins.int
    """The maximum number of playlists to return per page."""
    page_token: builtins.str
    """Page token for retrieving the next page of results.
    This token is obtained from the next_page_token field in the previous ListPlaylistsResponse.
    """
    order_by: builtins.str
    """Specifies the ordering of results.
    Format is "<field> <order>" (e.g., "createdAt desc").
    Default: "id asc".
    Supported fields: ["id", "title", "createdAt", "updatedAt"].
    Both snake_case and camelCase field names are supported.
    """
    filter: builtins.str
    """Filter expression to narrow down the list of returned playlists.
    Expressions consist of terms connected by logical operators.
    Values containing spaces or quotes must be enclosed in quotes (`'` or `"`)
    with inner quotes being backslash-escaped.

    Supported logical operators: ["AND", "OR"].
    Supported comparison operators: ["=", "!=", ":"] where ":" enables substring matching.
    Parentheses can be used to group logical expressions.

    Example: `title:'highlights' AND id='playlist-1'`

    Filterable fields: ["id", "title"].
    Both snake_case and camelCase field names are supported.
    """
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListPlaylistsRequest = ListPlaylistsRequest

@typing.final
class ListPlaylistsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLISTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for retrieving the next page of results.
    Empty if there are no more results available.
    """
    @property
    def playlists(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.playlist_pb2.Playlist]:
        """List of playlists matching the request criteria.
        May be empty if no playlists match the criteria or if the channel has no playlists.
        """

    def __init__(
        self,
        *,
        playlists: collections.abc.Iterable[yandex.cloud.video.v1.playlist_pb2.Playlist] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "playlists", b"playlists"]) -> None: ...

global___ListPlaylistsResponse = ListPlaylistsResponse

@typing.final
class CreatePlaylistRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel where the playlist will be created."""
    title: builtins.str
    """Title of the playlist to be displayed in interfaces and players."""
    description: builtins.str
    """Detailed description of the playlist content and context.
    Optional field that can provide additional information about the playlist.
    """
    style_preset_id: builtins.str
    """ID of the style preset to be applied to the playlist player.
    Style presets control the visual appearance of the player.
    """
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.playlist_pb2.PlaylistItem]:
        """List of items to include in the playlist.
        Each item represents a video or episode to be played in sequence.
        The order of items in this list determines the playback order.
        """

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        items: collections.abc.Iterable[yandex.cloud.video.v1.playlist_pb2.PlaylistItem] | None = ...,
        style_preset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "description", b"description", "items", b"items", "style_preset_id", b"style_preset_id", "title", b"title"]) -> None: ...

global___CreatePlaylistRequest = CreatePlaylistRequest

@typing.final
class CreatePlaylistMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_ID_FIELD_NUMBER: builtins.int
    playlist_id: builtins.str
    """ID of the playlist being created."""
    def __init__(
        self,
        *,
        playlist_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["playlist_id", b"playlist_id"]) -> None: ...

global___CreatePlaylistMetadata = CreatePlaylistMetadata

@typing.final
class UpdatePlaylistRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    playlist_id: builtins.str
    """ID of the playlist to update."""
    title: builtins.str
    """New title for the playlist."""
    description: builtins.str
    """New description for the playlist.
    Optional field that can provide additional information about the playlist.
    """
    style_preset_id: builtins.str
    """New ID of the style preset to be applied to the playlist player."""
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying which fields of the playlist should be updated.
        Only fields specified in this mask will be modified;
        all other fields will retain their current values.
        This allows for partial updates.
        """

    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.playlist_pb2.PlaylistItem]:
        """New list of items to include in the playlist.
        This completely replaces the existing items if specified in the field mask.
        The order of items in this list determines the playback order.
        """

    def __init__(
        self,
        *,
        playlist_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        items: collections.abc.Iterable[yandex.cloud.video.v1.playlist_pb2.PlaylistItem] | None = ...,
        style_preset_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["field_mask", b"field_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "field_mask", b"field_mask", "items", b"items", "playlist_id", b"playlist_id", "style_preset_id", b"style_preset_id", "title", b"title"]) -> None: ...

global___UpdatePlaylistRequest = UpdatePlaylistRequest

@typing.final
class UpdatePlaylistMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_ID_FIELD_NUMBER: builtins.int
    playlist_id: builtins.str
    """ID of the playlist being updated."""
    def __init__(
        self,
        *,
        playlist_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["playlist_id", b"playlist_id"]) -> None: ...

global___UpdatePlaylistMetadata = UpdatePlaylistMetadata

@typing.final
class DeletePlaylistRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_ID_FIELD_NUMBER: builtins.int
    playlist_id: builtins.str
    """ID of the playlist to delete."""
    def __init__(
        self,
        *,
        playlist_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["playlist_id", b"playlist_id"]) -> None: ...

global___DeletePlaylistRequest = DeletePlaylistRequest

@typing.final
class DeletePlaylistMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_ID_FIELD_NUMBER: builtins.int
    playlist_id: builtins.str
    """ID of the playlist being deleted.
    This identifier can be used to track the playlist deletion operation.
    """
    def __init__(
        self,
        *,
        playlist_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["playlist_id", b"playlist_id"]) -> None: ...

global___DeletePlaylistMetadata = DeletePlaylistMetadata

@typing.final
class BatchDeletePlaylistsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PLAYLIST_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the playlists to delete."""
    @property
    def playlist_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of playlist IDs to delete.
        All playlists must exist in the specified channel.
        """

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        playlist_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "playlist_ids", b"playlist_ids"]) -> None: ...

global___BatchDeletePlaylistsRequest = BatchDeletePlaylistsRequest

@typing.final
class BatchDeletePlaylistsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_IDS_FIELD_NUMBER: builtins.int
    @property
    def playlist_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of playlist IDs being deleted.
        This list can be used to track which playlists are included
        in the batch deletion operation.
        """

    def __init__(
        self,
        *,
        playlist_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["playlist_ids", b"playlist_ids"]) -> None: ...

global___BatchDeletePlaylistsMetadata = BatchDeletePlaylistsMetadata

@typing.final
class GetPlaylistPlayerURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYLIST_ID_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    playlist_id: builtins.str
    """ID of the playlist for which to generate a player URL."""
    @property
    def params(self) -> global___PlaylistPlayerParams:
        """Optional player parameters to customize the playback experience.
        These parameters control initial player state such as mute, autoplay, and visibility of interface controls.
        """

    def __init__(
        self,
        *,
        playlist_id: builtins.str = ...,
        params: global___PlaylistPlayerParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["params", b"params", "playlist_id", b"playlist_id"]) -> None: ...

global___GetPlaylistPlayerURLRequest = GetPlaylistPlayerURLRequest

@typing.final
class PlaylistPlayerParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MUTE_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    mute: builtins.bool
    """If true, the player will start with audio muted.
    Users can unmute the audio manually after playback starts.
    """
    autoplay: builtins.bool
    """If true, the playlist will start playing automatically when the player loads.
    This may be subject to browser autoplay policies that restrict autoplay with sound.
    """
    hidden: builtins.bool
    """If true, the player interface controls will be hidden initially.
    Users can typically reveal the controls by moving the mouse over the player.
    """
    def __init__(
        self,
        *,
        mute: builtins.bool = ...,
        autoplay: builtins.bool = ...,
        hidden: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["autoplay", b"autoplay", "hidden", b"hidden", "mute", b"mute"]) -> None: ...

global___PlaylistPlayerParams = PlaylistPlayerParams

@typing.final
class GetPlaylistPlayerURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYER_URL_FIELD_NUMBER: builtins.int
    HTML_FIELD_NUMBER: builtins.int
    player_url: builtins.str
    """Direct URL to the playlist player.
    This URL can be used to access the playlist in a web browser
    or shared with users who have appropriate permissions.
    """
    html: builtins.str
    """HTML embed code in iframe format that can be inserted into web pages.
    This code allows the playlist to be embedded directly in third-party websites.
    """
    def __init__(
        self,
        *,
        player_url: builtins.str = ...,
        html: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["html", b"html", "player_url", b"player_url"]) -> None: ...

global___GetPlaylistPlayerURLResponse = GetPlaylistPlayerURLResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PostgresqlConfig11_1C(google.protobuf.message.Message):
    """Options and structure of `PostgresqlConfig` reflects PostgreSQL configuration file
    parameters which detailed description is available in
    [PostgreSQL documentation](https://www.postgresql.org/docs/11/runtime-config.html).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _BackslashQuote:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _BackslashQuoteEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._BackslashQuote.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BACKSLASH_QUOTE_UNSPECIFIED: PostgresqlConfig11_1C._BackslashQuote.ValueType  # 0
        BACKSLASH_QUOTE: PostgresqlConfig11_1C._BackslashQuote.ValueType  # 1
        BACKSLASH_QUOTE_ON: PostgresqlConfig11_1C._BackslashQuote.ValueType  # 2
        BACKSLASH_QUOTE_OFF: PostgresqlConfig11_1C._BackslashQuote.ValueType  # 3
        BACKSLASH_QUOTE_SAFE_ENCODING: PostgresqlConfig11_1C._BackslashQuote.ValueType  # 4

    class BackslashQuote(_BackslashQuote, metaclass=_BackslashQuoteEnumTypeWrapper): ...
    BACKSLASH_QUOTE_UNSPECIFIED: PostgresqlConfig11_1C.BackslashQuote.ValueType  # 0
    BACKSLASH_QUOTE: PostgresqlConfig11_1C.BackslashQuote.ValueType  # 1
    BACKSLASH_QUOTE_ON: PostgresqlConfig11_1C.BackslashQuote.ValueType  # 2
    BACKSLASH_QUOTE_OFF: PostgresqlConfig11_1C.BackslashQuote.ValueType  # 3
    BACKSLASH_QUOTE_SAFE_ENCODING: PostgresqlConfig11_1C.BackslashQuote.ValueType  # 4

    class _ByteaOutput:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ByteaOutputEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._ByteaOutput.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BYTEA_OUTPUT_UNSPECIFIED: PostgresqlConfig11_1C._ByteaOutput.ValueType  # 0
        BYTEA_OUTPUT_HEX: PostgresqlConfig11_1C._ByteaOutput.ValueType  # 1
        BYTEA_OUTPUT_ESCAPED: PostgresqlConfig11_1C._ByteaOutput.ValueType  # 2

    class ByteaOutput(_ByteaOutput, metaclass=_ByteaOutputEnumTypeWrapper): ...
    BYTEA_OUTPUT_UNSPECIFIED: PostgresqlConfig11_1C.ByteaOutput.ValueType  # 0
    BYTEA_OUTPUT_HEX: PostgresqlConfig11_1C.ByteaOutput.ValueType  # 1
    BYTEA_OUTPUT_ESCAPED: PostgresqlConfig11_1C.ByteaOutput.ValueType  # 2

    class _ConstraintExclusion:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ConstraintExclusionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._ConstraintExclusion.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CONSTRAINT_EXCLUSION_UNSPECIFIED: PostgresqlConfig11_1C._ConstraintExclusion.ValueType  # 0
        CONSTRAINT_EXCLUSION_ON: PostgresqlConfig11_1C._ConstraintExclusion.ValueType  # 1
        CONSTRAINT_EXCLUSION_OFF: PostgresqlConfig11_1C._ConstraintExclusion.ValueType  # 2
        CONSTRAINT_EXCLUSION_PARTITION: PostgresqlConfig11_1C._ConstraintExclusion.ValueType  # 3

    class ConstraintExclusion(_ConstraintExclusion, metaclass=_ConstraintExclusionEnumTypeWrapper): ...
    CONSTRAINT_EXCLUSION_UNSPECIFIED: PostgresqlConfig11_1C.ConstraintExclusion.ValueType  # 0
    CONSTRAINT_EXCLUSION_ON: PostgresqlConfig11_1C.ConstraintExclusion.ValueType  # 1
    CONSTRAINT_EXCLUSION_OFF: PostgresqlConfig11_1C.ConstraintExclusion.ValueType  # 2
    CONSTRAINT_EXCLUSION_PARTITION: PostgresqlConfig11_1C.ConstraintExclusion.ValueType  # 3

    class _ForceParallelMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ForceParallelModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._ForceParallelMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FORCE_PARALLEL_MODE_UNSPECIFIED: PostgresqlConfig11_1C._ForceParallelMode.ValueType  # 0
        FORCE_PARALLEL_MODE_ON: PostgresqlConfig11_1C._ForceParallelMode.ValueType  # 1
        FORCE_PARALLEL_MODE_OFF: PostgresqlConfig11_1C._ForceParallelMode.ValueType  # 2
        FORCE_PARALLEL_MODE_REGRESS: PostgresqlConfig11_1C._ForceParallelMode.ValueType  # 3

    class ForceParallelMode(_ForceParallelMode, metaclass=_ForceParallelModeEnumTypeWrapper): ...
    FORCE_PARALLEL_MODE_UNSPECIFIED: PostgresqlConfig11_1C.ForceParallelMode.ValueType  # 0
    FORCE_PARALLEL_MODE_ON: PostgresqlConfig11_1C.ForceParallelMode.ValueType  # 1
    FORCE_PARALLEL_MODE_OFF: PostgresqlConfig11_1C.ForceParallelMode.ValueType  # 2
    FORCE_PARALLEL_MODE_REGRESS: PostgresqlConfig11_1C.ForceParallelMode.ValueType  # 3

    class _LogErrorVerbosity:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogErrorVerbosityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._LogErrorVerbosity.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_ERROR_VERBOSITY_UNSPECIFIED: PostgresqlConfig11_1C._LogErrorVerbosity.ValueType  # 0
        LOG_ERROR_VERBOSITY_TERSE: PostgresqlConfig11_1C._LogErrorVerbosity.ValueType  # 1
        LOG_ERROR_VERBOSITY_DEFAULT: PostgresqlConfig11_1C._LogErrorVerbosity.ValueType  # 2
        LOG_ERROR_VERBOSITY_VERBOSE: PostgresqlConfig11_1C._LogErrorVerbosity.ValueType  # 3

    class LogErrorVerbosity(_LogErrorVerbosity, metaclass=_LogErrorVerbosityEnumTypeWrapper): ...
    LOG_ERROR_VERBOSITY_UNSPECIFIED: PostgresqlConfig11_1C.LogErrorVerbosity.ValueType  # 0
    LOG_ERROR_VERBOSITY_TERSE: PostgresqlConfig11_1C.LogErrorVerbosity.ValueType  # 1
    LOG_ERROR_VERBOSITY_DEFAULT: PostgresqlConfig11_1C.LogErrorVerbosity.ValueType  # 2
    LOG_ERROR_VERBOSITY_VERBOSE: PostgresqlConfig11_1C.LogErrorVerbosity.ValueType  # 3

    class _LogLevel:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._LogLevel.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_LEVEL_UNSPECIFIED: PostgresqlConfig11_1C._LogLevel.ValueType  # 0
        LOG_LEVEL_DEBUG5: PostgresqlConfig11_1C._LogLevel.ValueType  # 1
        LOG_LEVEL_DEBUG4: PostgresqlConfig11_1C._LogLevel.ValueType  # 2
        LOG_LEVEL_DEBUG3: PostgresqlConfig11_1C._LogLevel.ValueType  # 3
        LOG_LEVEL_DEBUG2: PostgresqlConfig11_1C._LogLevel.ValueType  # 4
        LOG_LEVEL_DEBUG1: PostgresqlConfig11_1C._LogLevel.ValueType  # 5
        LOG_LEVEL_LOG: PostgresqlConfig11_1C._LogLevel.ValueType  # 6
        LOG_LEVEL_NOTICE: PostgresqlConfig11_1C._LogLevel.ValueType  # 7
        LOG_LEVEL_WARNING: PostgresqlConfig11_1C._LogLevel.ValueType  # 8
        LOG_LEVEL_ERROR: PostgresqlConfig11_1C._LogLevel.ValueType  # 9
        LOG_LEVEL_FATAL: PostgresqlConfig11_1C._LogLevel.ValueType  # 10
        LOG_LEVEL_PANIC: PostgresqlConfig11_1C._LogLevel.ValueType  # 11

    class LogLevel(_LogLevel, metaclass=_LogLevelEnumTypeWrapper): ...
    LOG_LEVEL_UNSPECIFIED: PostgresqlConfig11_1C.LogLevel.ValueType  # 0
    LOG_LEVEL_DEBUG5: PostgresqlConfig11_1C.LogLevel.ValueType  # 1
    LOG_LEVEL_DEBUG4: PostgresqlConfig11_1C.LogLevel.ValueType  # 2
    LOG_LEVEL_DEBUG3: PostgresqlConfig11_1C.LogLevel.ValueType  # 3
    LOG_LEVEL_DEBUG2: PostgresqlConfig11_1C.LogLevel.ValueType  # 4
    LOG_LEVEL_DEBUG1: PostgresqlConfig11_1C.LogLevel.ValueType  # 5
    LOG_LEVEL_LOG: PostgresqlConfig11_1C.LogLevel.ValueType  # 6
    LOG_LEVEL_NOTICE: PostgresqlConfig11_1C.LogLevel.ValueType  # 7
    LOG_LEVEL_WARNING: PostgresqlConfig11_1C.LogLevel.ValueType  # 8
    LOG_LEVEL_ERROR: PostgresqlConfig11_1C.LogLevel.ValueType  # 9
    LOG_LEVEL_FATAL: PostgresqlConfig11_1C.LogLevel.ValueType  # 10
    LOG_LEVEL_PANIC: PostgresqlConfig11_1C.LogLevel.ValueType  # 11

    class _LogStatement:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogStatementEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._LogStatement.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_STATEMENT_UNSPECIFIED: PostgresqlConfig11_1C._LogStatement.ValueType  # 0
        LOG_STATEMENT_NONE: PostgresqlConfig11_1C._LogStatement.ValueType  # 1
        LOG_STATEMENT_DDL: PostgresqlConfig11_1C._LogStatement.ValueType  # 2
        LOG_STATEMENT_MOD: PostgresqlConfig11_1C._LogStatement.ValueType  # 3
        LOG_STATEMENT_ALL: PostgresqlConfig11_1C._LogStatement.ValueType  # 4

    class LogStatement(_LogStatement, metaclass=_LogStatementEnumTypeWrapper): ...
    LOG_STATEMENT_UNSPECIFIED: PostgresqlConfig11_1C.LogStatement.ValueType  # 0
    LOG_STATEMENT_NONE: PostgresqlConfig11_1C.LogStatement.ValueType  # 1
    LOG_STATEMENT_DDL: PostgresqlConfig11_1C.LogStatement.ValueType  # 2
    LOG_STATEMENT_MOD: PostgresqlConfig11_1C.LogStatement.ValueType  # 3
    LOG_STATEMENT_ALL: PostgresqlConfig11_1C.LogStatement.ValueType  # 4

    class _PasswordEncryption:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PasswordEncryptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._PasswordEncryption.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PASSWORD_ENCRYPTION_UNSPECIFIED: PostgresqlConfig11_1C._PasswordEncryption.ValueType  # 0
        PASSWORD_ENCRYPTION_MD5: PostgresqlConfig11_1C._PasswordEncryption.ValueType  # 1
        PASSWORD_ENCRYPTION_SCRAM_SHA_256: PostgresqlConfig11_1C._PasswordEncryption.ValueType  # 2

    class PasswordEncryption(_PasswordEncryption, metaclass=_PasswordEncryptionEnumTypeWrapper): ...
    PASSWORD_ENCRYPTION_UNSPECIFIED: PostgresqlConfig11_1C.PasswordEncryption.ValueType  # 0
    PASSWORD_ENCRYPTION_MD5: PostgresqlConfig11_1C.PasswordEncryption.ValueType  # 1
    PASSWORD_ENCRYPTION_SCRAM_SHA_256: PostgresqlConfig11_1C.PasswordEncryption.ValueType  # 2

    class _PgHintPlanDebugPrint:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PgHintPlanDebugPrintEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._PgHintPlanDebugPrint.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PG_HINT_PLAN_DEBUG_PRINT_UNSPECIFIED: PostgresqlConfig11_1C._PgHintPlanDebugPrint.ValueType  # 0
        PG_HINT_PLAN_DEBUG_PRINT_OFF: PostgresqlConfig11_1C._PgHintPlanDebugPrint.ValueType  # 1
        PG_HINT_PLAN_DEBUG_PRINT_ON: PostgresqlConfig11_1C._PgHintPlanDebugPrint.ValueType  # 2
        PG_HINT_PLAN_DEBUG_PRINT_DETAILED: PostgresqlConfig11_1C._PgHintPlanDebugPrint.ValueType  # 3
        PG_HINT_PLAN_DEBUG_PRINT_VERBOSE: PostgresqlConfig11_1C._PgHintPlanDebugPrint.ValueType  # 4

    class PgHintPlanDebugPrint(_PgHintPlanDebugPrint, metaclass=_PgHintPlanDebugPrintEnumTypeWrapper): ...
    PG_HINT_PLAN_DEBUG_PRINT_UNSPECIFIED: PostgresqlConfig11_1C.PgHintPlanDebugPrint.ValueType  # 0
    PG_HINT_PLAN_DEBUG_PRINT_OFF: PostgresqlConfig11_1C.PgHintPlanDebugPrint.ValueType  # 1
    PG_HINT_PLAN_DEBUG_PRINT_ON: PostgresqlConfig11_1C.PgHintPlanDebugPrint.ValueType  # 2
    PG_HINT_PLAN_DEBUG_PRINT_DETAILED: PostgresqlConfig11_1C.PgHintPlanDebugPrint.ValueType  # 3
    PG_HINT_PLAN_DEBUG_PRINT_VERBOSE: PostgresqlConfig11_1C.PgHintPlanDebugPrint.ValueType  # 4

    class _SharedPreloadLibraries:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SharedPreloadLibrariesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._SharedPreloadLibraries.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SHARED_PRELOAD_LIBRARIES_UNSPECIFIED: PostgresqlConfig11_1C._SharedPreloadLibraries.ValueType  # 0
        SHARED_PRELOAD_LIBRARIES_AUTO_EXPLAIN: PostgresqlConfig11_1C._SharedPreloadLibraries.ValueType  # 1
        SHARED_PRELOAD_LIBRARIES_PG_HINT_PLAN: PostgresqlConfig11_1C._SharedPreloadLibraries.ValueType  # 2
        SHARED_PRELOAD_LIBRARIES_TIMESCALEDB: PostgresqlConfig11_1C._SharedPreloadLibraries.ValueType  # 3
        SHARED_PRELOAD_LIBRARIES_PG_QUALSTATS: PostgresqlConfig11_1C._SharedPreloadLibraries.ValueType  # 4
        SHARED_PRELOAD_LIBRARIES_PG_CRON: PostgresqlConfig11_1C._SharedPreloadLibraries.ValueType  # 5
        SHARED_PRELOAD_LIBRARIES_PGLOGICAL: PostgresqlConfig11_1C._SharedPreloadLibraries.ValueType  # 6
        SHARED_PRELOAD_LIBRARIES_PG_PREWARM: PostgresqlConfig11_1C._SharedPreloadLibraries.ValueType  # 7
        SHARED_PRELOAD_LIBRARIES_PGAUDIT: PostgresqlConfig11_1C._SharedPreloadLibraries.ValueType  # 8

    class SharedPreloadLibraries(_SharedPreloadLibraries, metaclass=_SharedPreloadLibrariesEnumTypeWrapper): ...
    SHARED_PRELOAD_LIBRARIES_UNSPECIFIED: PostgresqlConfig11_1C.SharedPreloadLibraries.ValueType  # 0
    SHARED_PRELOAD_LIBRARIES_AUTO_EXPLAIN: PostgresqlConfig11_1C.SharedPreloadLibraries.ValueType  # 1
    SHARED_PRELOAD_LIBRARIES_PG_HINT_PLAN: PostgresqlConfig11_1C.SharedPreloadLibraries.ValueType  # 2
    SHARED_PRELOAD_LIBRARIES_TIMESCALEDB: PostgresqlConfig11_1C.SharedPreloadLibraries.ValueType  # 3
    SHARED_PRELOAD_LIBRARIES_PG_QUALSTATS: PostgresqlConfig11_1C.SharedPreloadLibraries.ValueType  # 4
    SHARED_PRELOAD_LIBRARIES_PG_CRON: PostgresqlConfig11_1C.SharedPreloadLibraries.ValueType  # 5
    SHARED_PRELOAD_LIBRARIES_PGLOGICAL: PostgresqlConfig11_1C.SharedPreloadLibraries.ValueType  # 6
    SHARED_PRELOAD_LIBRARIES_PG_PREWARM: PostgresqlConfig11_1C.SharedPreloadLibraries.ValueType  # 7
    SHARED_PRELOAD_LIBRARIES_PGAUDIT: PostgresqlConfig11_1C.SharedPreloadLibraries.ValueType  # 8

    class _SynchronousCommit:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SynchronousCommitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._SynchronousCommit.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SYNCHRONOUS_COMMIT_UNSPECIFIED: PostgresqlConfig11_1C._SynchronousCommit.ValueType  # 0
        SYNCHRONOUS_COMMIT_ON: PostgresqlConfig11_1C._SynchronousCommit.ValueType  # 1
        SYNCHRONOUS_COMMIT_OFF: PostgresqlConfig11_1C._SynchronousCommit.ValueType  # 2
        SYNCHRONOUS_COMMIT_LOCAL: PostgresqlConfig11_1C._SynchronousCommit.ValueType  # 3
        SYNCHRONOUS_COMMIT_REMOTE_WRITE: PostgresqlConfig11_1C._SynchronousCommit.ValueType  # 4
        SYNCHRONOUS_COMMIT_REMOTE_APPLY: PostgresqlConfig11_1C._SynchronousCommit.ValueType  # 5

    class SynchronousCommit(_SynchronousCommit, metaclass=_SynchronousCommitEnumTypeWrapper): ...
    SYNCHRONOUS_COMMIT_UNSPECIFIED: PostgresqlConfig11_1C.SynchronousCommit.ValueType  # 0
    SYNCHRONOUS_COMMIT_ON: PostgresqlConfig11_1C.SynchronousCommit.ValueType  # 1
    SYNCHRONOUS_COMMIT_OFF: PostgresqlConfig11_1C.SynchronousCommit.ValueType  # 2
    SYNCHRONOUS_COMMIT_LOCAL: PostgresqlConfig11_1C.SynchronousCommit.ValueType  # 3
    SYNCHRONOUS_COMMIT_REMOTE_WRITE: PostgresqlConfig11_1C.SynchronousCommit.ValueType  # 4
    SYNCHRONOUS_COMMIT_REMOTE_APPLY: PostgresqlConfig11_1C.SynchronousCommit.ValueType  # 5

    class _TransactionIsolation:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TransactionIsolationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._TransactionIsolation.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TRANSACTION_ISOLATION_UNSPECIFIED: PostgresqlConfig11_1C._TransactionIsolation.ValueType  # 0
        TRANSACTION_ISOLATION_READ_UNCOMMITTED: PostgresqlConfig11_1C._TransactionIsolation.ValueType  # 1
        TRANSACTION_ISOLATION_READ_COMMITTED: PostgresqlConfig11_1C._TransactionIsolation.ValueType  # 2
        TRANSACTION_ISOLATION_REPEATABLE_READ: PostgresqlConfig11_1C._TransactionIsolation.ValueType  # 3
        TRANSACTION_ISOLATION_SERIALIZABLE: PostgresqlConfig11_1C._TransactionIsolation.ValueType  # 4

    class TransactionIsolation(_TransactionIsolation, metaclass=_TransactionIsolationEnumTypeWrapper): ...
    TRANSACTION_ISOLATION_UNSPECIFIED: PostgresqlConfig11_1C.TransactionIsolation.ValueType  # 0
    TRANSACTION_ISOLATION_READ_UNCOMMITTED: PostgresqlConfig11_1C.TransactionIsolation.ValueType  # 1
    TRANSACTION_ISOLATION_READ_COMMITTED: PostgresqlConfig11_1C.TransactionIsolation.ValueType  # 2
    TRANSACTION_ISOLATION_REPEATABLE_READ: PostgresqlConfig11_1C.TransactionIsolation.ValueType  # 3
    TRANSACTION_ISOLATION_SERIALIZABLE: PostgresqlConfig11_1C.TransactionIsolation.ValueType  # 4

    class _WalLevel:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _WalLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._WalLevel.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        WAL_LEVEL_UNSPECIFIED: PostgresqlConfig11_1C._WalLevel.ValueType  # 0
        WAL_LEVEL_REPLICA: PostgresqlConfig11_1C._WalLevel.ValueType  # 1
        WAL_LEVEL_LOGICAL: PostgresqlConfig11_1C._WalLevel.ValueType  # 2

    class WalLevel(_WalLevel, metaclass=_WalLevelEnumTypeWrapper): ...
    WAL_LEVEL_UNSPECIFIED: PostgresqlConfig11_1C.WalLevel.ValueType  # 0
    WAL_LEVEL_REPLICA: PostgresqlConfig11_1C.WalLevel.ValueType  # 1
    WAL_LEVEL_LOGICAL: PostgresqlConfig11_1C.WalLevel.ValueType  # 2

    class _XmlBinary:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _XmlBinaryEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._XmlBinary.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        XML_BINARY_UNSPECIFIED: PostgresqlConfig11_1C._XmlBinary.ValueType  # 0
        XML_BINARY_BASE64: PostgresqlConfig11_1C._XmlBinary.ValueType  # 1
        XML_BINARY_HEX: PostgresqlConfig11_1C._XmlBinary.ValueType  # 2

    class XmlBinary(_XmlBinary, metaclass=_XmlBinaryEnumTypeWrapper): ...
    XML_BINARY_UNSPECIFIED: PostgresqlConfig11_1C.XmlBinary.ValueType  # 0
    XML_BINARY_BASE64: PostgresqlConfig11_1C.XmlBinary.ValueType  # 1
    XML_BINARY_HEX: PostgresqlConfig11_1C.XmlBinary.ValueType  # 2

    class _XmlOption:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _XmlOptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlConfig11_1C._XmlOption.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        XML_OPTION_UNSPECIFIED: PostgresqlConfig11_1C._XmlOption.ValueType  # 0
        XML_OPTION_DOCUMENT: PostgresqlConfig11_1C._XmlOption.ValueType  # 1
        XML_OPTION_CONTENT: PostgresqlConfig11_1C._XmlOption.ValueType  # 2

    class XmlOption(_XmlOption, metaclass=_XmlOptionEnumTypeWrapper): ...
    XML_OPTION_UNSPECIFIED: PostgresqlConfig11_1C.XmlOption.ValueType  # 0
    XML_OPTION_DOCUMENT: PostgresqlConfig11_1C.XmlOption.ValueType  # 1
    XML_OPTION_CONTENT: PostgresqlConfig11_1C.XmlOption.ValueType  # 2

    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    SHARED_BUFFERS_FIELD_NUMBER: builtins.int
    TEMP_BUFFERS_FIELD_NUMBER: builtins.int
    MAX_PREPARED_TRANSACTIONS_FIELD_NUMBER: builtins.int
    WORK_MEM_FIELD_NUMBER: builtins.int
    MAINTENANCE_WORK_MEM_FIELD_NUMBER: builtins.int
    AUTOVACUUM_WORK_MEM_FIELD_NUMBER: builtins.int
    TEMP_FILE_LIMIT_FIELD_NUMBER: builtins.int
    VACUUM_COST_DELAY_FIELD_NUMBER: builtins.int
    VACUUM_COST_PAGE_HIT_FIELD_NUMBER: builtins.int
    VACUUM_COST_PAGE_MISS_FIELD_NUMBER: builtins.int
    VACUUM_COST_PAGE_DIRTY_FIELD_NUMBER: builtins.int
    VACUUM_COST_LIMIT_FIELD_NUMBER: builtins.int
    BGWRITER_DELAY_FIELD_NUMBER: builtins.int
    BGWRITER_LRU_MAXPAGES_FIELD_NUMBER: builtins.int
    BGWRITER_LRU_MULTIPLIER_FIELD_NUMBER: builtins.int
    BGWRITER_FLUSH_AFTER_FIELD_NUMBER: builtins.int
    BACKEND_FLUSH_AFTER_FIELD_NUMBER: builtins.int
    OLD_SNAPSHOT_THRESHOLD_FIELD_NUMBER: builtins.int
    WAL_LEVEL_FIELD_NUMBER: builtins.int
    SYNCHRONOUS_COMMIT_FIELD_NUMBER: builtins.int
    CHECKPOINT_TIMEOUT_FIELD_NUMBER: builtins.int
    CHECKPOINT_COMPLETION_TARGET_FIELD_NUMBER: builtins.int
    CHECKPOINT_FLUSH_AFTER_FIELD_NUMBER: builtins.int
    MAX_WAL_SIZE_FIELD_NUMBER: builtins.int
    MIN_WAL_SIZE_FIELD_NUMBER: builtins.int
    MAX_STANDBY_STREAMING_DELAY_FIELD_NUMBER: builtins.int
    DEFAULT_STATISTICS_TARGET_FIELD_NUMBER: builtins.int
    CONSTRAINT_EXCLUSION_FIELD_NUMBER: builtins.int
    CURSOR_TUPLE_FRACTION_FIELD_NUMBER: builtins.int
    FROM_COLLAPSE_LIMIT_FIELD_NUMBER: builtins.int
    JOIN_COLLAPSE_LIMIT_FIELD_NUMBER: builtins.int
    FORCE_PARALLEL_MODE_FIELD_NUMBER: builtins.int
    CLIENT_MIN_MESSAGES_FIELD_NUMBER: builtins.int
    LOG_MIN_MESSAGES_FIELD_NUMBER: builtins.int
    LOG_MIN_ERROR_STATEMENT_FIELD_NUMBER: builtins.int
    LOG_MIN_DURATION_STATEMENT_FIELD_NUMBER: builtins.int
    LOG_CHECKPOINTS_FIELD_NUMBER: builtins.int
    LOG_CONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_DISCONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_DURATION_FIELD_NUMBER: builtins.int
    LOG_ERROR_VERBOSITY_FIELD_NUMBER: builtins.int
    LOG_LOCK_WAITS_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_FIELD_NUMBER: builtins.int
    LOG_TEMP_FILES_FIELD_NUMBER: builtins.int
    SEARCH_PATH_FIELD_NUMBER: builtins.int
    ROW_SECURITY_FIELD_NUMBER: builtins.int
    DEFAULT_TRANSACTION_ISOLATION_FIELD_NUMBER: builtins.int
    STATEMENT_TIMEOUT_FIELD_NUMBER: builtins.int
    LOCK_TIMEOUT_FIELD_NUMBER: builtins.int
    IDLE_IN_TRANSACTION_SESSION_TIMEOUT_FIELD_NUMBER: builtins.int
    BYTEA_OUTPUT_FIELD_NUMBER: builtins.int
    XMLBINARY_FIELD_NUMBER: builtins.int
    XMLOPTION_FIELD_NUMBER: builtins.int
    GIN_PENDING_LIST_LIMIT_FIELD_NUMBER: builtins.int
    DEADLOCK_TIMEOUT_FIELD_NUMBER: builtins.int
    MAX_LOCKS_PER_TRANSACTION_FIELD_NUMBER: builtins.int
    MAX_PRED_LOCKS_PER_TRANSACTION_FIELD_NUMBER: builtins.int
    ARRAY_NULLS_FIELD_NUMBER: builtins.int
    BACKSLASH_QUOTE_FIELD_NUMBER: builtins.int
    DEFAULT_WITH_OIDS_FIELD_NUMBER: builtins.int
    ESCAPE_STRING_WARNING_FIELD_NUMBER: builtins.int
    LO_COMPAT_PRIVILEGES_FIELD_NUMBER: builtins.int
    OPERATOR_PRECEDENCE_WARNING_FIELD_NUMBER: builtins.int
    QUOTE_ALL_IDENTIFIERS_FIELD_NUMBER: builtins.int
    STANDARD_CONFORMING_STRINGS_FIELD_NUMBER: builtins.int
    SYNCHRONIZE_SEQSCANS_FIELD_NUMBER: builtins.int
    TRANSFORM_NULL_EQUALS_FIELD_NUMBER: builtins.int
    EXIT_ON_ERROR_FIELD_NUMBER: builtins.int
    SEQ_PAGE_COST_FIELD_NUMBER: builtins.int
    RANDOM_PAGE_COST_FIELD_NUMBER: builtins.int
    AUTOVACUUM_MAX_WORKERS_FIELD_NUMBER: builtins.int
    AUTOVACUUM_VACUUM_COST_DELAY_FIELD_NUMBER: builtins.int
    AUTOVACUUM_VACUUM_COST_LIMIT_FIELD_NUMBER: builtins.int
    AUTOVACUUM_NAPTIME_FIELD_NUMBER: builtins.int
    ARCHIVE_TIMEOUT_FIELD_NUMBER: builtins.int
    TRACK_ACTIVITY_QUERY_SIZE_FIELD_NUMBER: builtins.int
    ONLINE_ANALYZE_ENABLE_FIELD_NUMBER: builtins.int
    ENABLE_BITMAPSCAN_FIELD_NUMBER: builtins.int
    ENABLE_HASHAGG_FIELD_NUMBER: builtins.int
    ENABLE_HASHJOIN_FIELD_NUMBER: builtins.int
    ENABLE_INDEXSCAN_FIELD_NUMBER: builtins.int
    ENABLE_INDEXONLYSCAN_FIELD_NUMBER: builtins.int
    ENABLE_MATERIAL_FIELD_NUMBER: builtins.int
    ENABLE_MERGEJOIN_FIELD_NUMBER: builtins.int
    ENABLE_NESTLOOP_FIELD_NUMBER: builtins.int
    ENABLE_SEQSCAN_FIELD_NUMBER: builtins.int
    ENABLE_SORT_FIELD_NUMBER: builtins.int
    ENABLE_TIDSCAN_FIELD_NUMBER: builtins.int
    MAX_WORKER_PROCESSES_FIELD_NUMBER: builtins.int
    MAX_PARALLEL_WORKERS_FIELD_NUMBER: builtins.int
    MAX_PARALLEL_WORKERS_PER_GATHER_FIELD_NUMBER: builtins.int
    AUTOVACUUM_VACUUM_SCALE_FACTOR_FIELD_NUMBER: builtins.int
    AUTOVACUUM_ANALYZE_SCALE_FACTOR_FIELD_NUMBER: builtins.int
    DEFAULT_TRANSACTION_READ_ONLY_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    ENABLE_PARALLEL_APPEND_FIELD_NUMBER: builtins.int
    ENABLE_PARALLEL_HASH_FIELD_NUMBER: builtins.int
    ENABLE_PARTITION_PRUNING_FIELD_NUMBER: builtins.int
    ENABLE_PARTITIONWISE_AGGREGATE_FIELD_NUMBER: builtins.int
    ENABLE_PARTITIONWISE_JOIN_FIELD_NUMBER: builtins.int
    JIT_FIELD_NUMBER: builtins.int
    MAX_PARALLEL_MAINTENANCE_WORKERS_FIELD_NUMBER: builtins.int
    PARALLEL_LEADER_PARTICIPATION_FIELD_NUMBER: builtins.int
    VACUUM_CLEANUP_INDEX_SCALE_FACTOR_FIELD_NUMBER: builtins.int
    EFFECTIVE_IO_CONCURRENCY_FIELD_NUMBER: builtins.int
    EFFECTIVE_CACHE_SIZE_FIELD_NUMBER: builtins.int
    SHARED_PRELOAD_LIBRARIES_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_LOG_MIN_DURATION_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_LOG_ANALYZE_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_LOG_BUFFERS_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_LOG_TIMING_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_LOG_TRIGGERS_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_LOG_VERBOSE_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_LOG_NESTED_STATEMENTS_FIELD_NUMBER: builtins.int
    AUTO_EXPLAIN_SAMPLE_RATE_FIELD_NUMBER: builtins.int
    PG_HINT_PLAN_ENABLE_HINT_FIELD_NUMBER: builtins.int
    PG_HINT_PLAN_ENABLE_HINT_TABLE_FIELD_NUMBER: builtins.int
    PG_HINT_PLAN_DEBUG_PRINT_FIELD_NUMBER: builtins.int
    PG_HINT_PLAN_MESSAGE_LEVEL_FIELD_NUMBER: builtins.int
    PG_QUALSTATS_ENABLED_FIELD_NUMBER: builtins.int
    PG_QUALSTATS_TRACK_CONSTANTS_FIELD_NUMBER: builtins.int
    PG_QUALSTATS_MAX_FIELD_NUMBER: builtins.int
    PG_QUALSTATS_RESOLVE_OIDS_FIELD_NUMBER: builtins.int
    PG_QUALSTATS_SAMPLE_RATE_FIELD_NUMBER: builtins.int
    PLANTUNER_FIX_EMPTY_TABLE_FIELD_NUMBER: builtins.int
    MAX_STACK_DEPTH_FIELD_NUMBER: builtins.int
    GEQO_FIELD_NUMBER: builtins.int
    GEQO_THRESHOLD_FIELD_NUMBER: builtins.int
    GEQO_EFFORT_FIELD_NUMBER: builtins.int
    GEQO_POOL_SIZE_FIELD_NUMBER: builtins.int
    GEQO_GENERATIONS_FIELD_NUMBER: builtins.int
    GEQO_SELECTION_BIAS_FIELD_NUMBER: builtins.int
    GEQO_SEED_FIELD_NUMBER: builtins.int
    PG_TRGM_SIMILARITY_THRESHOLD_FIELD_NUMBER: builtins.int
    PG_TRGM_WORD_SIMILARITY_THRESHOLD_FIELD_NUMBER: builtins.int
    PG_TRGM_STRICT_WORD_SIMILARITY_THRESHOLD_FIELD_NUMBER: builtins.int
    MAX_STANDBY_ARCHIVE_DELAY_FIELD_NUMBER: builtins.int
    SESSION_DURATION_TIMEOUT_FIELD_NUMBER: builtins.int
    LOG_REPLICATION_COMMANDS_FIELD_NUMBER: builtins.int
    LOG_AUTOVACUUM_MIN_DURATION_FIELD_NUMBER: builtins.int
    PASSWORD_ENCRYPTION_FIELD_NUMBER: builtins.int
    wal_level: global___PostgresqlConfig11_1C.WalLevel.ValueType
    synchronous_commit: global___PostgresqlConfig11_1C.SynchronousCommit.ValueType
    constraint_exclusion: global___PostgresqlConfig11_1C.ConstraintExclusion.ValueType
    force_parallel_mode: global___PostgresqlConfig11_1C.ForceParallelMode.ValueType
    client_min_messages: global___PostgresqlConfig11_1C.LogLevel.ValueType
    log_min_messages: global___PostgresqlConfig11_1C.LogLevel.ValueType
    log_min_error_statement: global___PostgresqlConfig11_1C.LogLevel.ValueType
    log_error_verbosity: global___PostgresqlConfig11_1C.LogErrorVerbosity.ValueType
    log_statement: global___PostgresqlConfig11_1C.LogStatement.ValueType
    search_path: builtins.str
    default_transaction_isolation: global___PostgresqlConfig11_1C.TransactionIsolation.ValueType
    bytea_output: global___PostgresqlConfig11_1C.ByteaOutput.ValueType
    xmlbinary: global___PostgresqlConfig11_1C.XmlBinary.ValueType
    xmloption: global___PostgresqlConfig11_1C.XmlOption.ValueType
    backslash_quote: global___PostgresqlConfig11_1C.BackslashQuote.ValueType
    timezone: builtins.str
    pg_hint_plan_debug_print: global___PostgresqlConfig11_1C.PgHintPlanDebugPrint.ValueType
    pg_hint_plan_message_level: global___PostgresqlConfig11_1C.LogLevel.ValueType
    password_encryption: global___PostgresqlConfig11_1C.PasswordEncryption.ValueType
    """A default value for `` user_password_encryption `` user-level setting, if it not specified for new users. Possible values are `` PASSWORD_ENCRYPTION_MD5 `` or `` PASSWORD_ENCRYPTION_SCRAM_SHA_256 ``. The default is `` PASSWORD_ENCRYPTION_MD5 ``."""
    @property
    def max_connections(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def shared_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def temp_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def max_prepared_transactions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def work_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def maintenance_work_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def autovacuum_work_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def temp_file_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def vacuum_cost_delay(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def vacuum_cost_page_hit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def vacuum_cost_page_miss(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def vacuum_cost_page_dirty(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def vacuum_cost_limit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def bgwriter_delay(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def bgwriter_lru_maxpages(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def bgwriter_lru_multiplier(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def bgwriter_flush_after(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes"""

    @property
    def backend_flush_after(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes"""

    @property
    def old_snapshot_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def checkpoint_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def checkpoint_completion_target(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def checkpoint_flush_after(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes"""

    @property
    def max_wal_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def min_wal_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def max_standby_streaming_delay(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def default_statistics_target(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def cursor_tuple_fraction(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def from_collapse_limit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def join_collapse_limit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def log_min_duration_statement(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def log_checkpoints(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_connections(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_disconnections(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_duration(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_lock_waits(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_temp_files(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def row_security(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def statement_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def lock_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def idle_in_transaction_session_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def gin_pending_list_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def deadlock_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def max_locks_per_transaction(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def max_pred_locks_per_transaction(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def array_nulls(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def default_with_oids(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def escape_string_warning(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def lo_compat_privileges(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def operator_precedence_warning(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def quote_all_identifiers(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def standard_conforming_strings(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def synchronize_seqscans(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def transform_null_equals(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def exit_on_error(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def seq_page_cost(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def random_page_cost(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def autovacuum_max_workers(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def autovacuum_vacuum_cost_delay(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def autovacuum_vacuum_cost_limit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def autovacuum_naptime(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def archive_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def track_activity_query_size(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def online_analyze_enable(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_bitmapscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_hashagg(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_hashjoin(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_indexscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_indexonlyscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_material(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_mergejoin(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_nestloop(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_seqscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_sort(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_tidscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def max_worker_processes(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def max_parallel_workers(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def max_parallel_workers_per_gather(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def autovacuum_vacuum_scale_factor(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def autovacuum_analyze_scale_factor(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def default_transaction_read_only(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_parallel_append(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_parallel_hash(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_partition_pruning(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_partitionwise_aggregate(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_partitionwise_join(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def jit(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def max_parallel_maintenance_workers(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def parallel_leader_participation(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def vacuum_cleanup_index_scale_factor(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def effective_io_concurrency(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def effective_cache_size(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def shared_preload_libraries(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___PostgresqlConfig11_1C.SharedPreloadLibraries.ValueType]: ...
    @property
    def auto_explain_log_min_duration(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def auto_explain_log_analyze(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def auto_explain_log_buffers(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def auto_explain_log_timing(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def auto_explain_log_triggers(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def auto_explain_log_verbose(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def auto_explain_log_nested_statements(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def auto_explain_sample_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def pg_hint_plan_enable_hint(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def pg_hint_plan_enable_hint_table(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def pg_qualstats_enabled(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def pg_qualstats_track_constants(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def pg_qualstats_max(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def pg_qualstats_resolve_oids(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def pg_qualstats_sample_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def plantuner_fix_empty_table(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def max_stack_depth(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def geqo(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """enable Genetic Query Optimizer, by default is on"""

    @property
    def geqo_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of tables to use geqo, default is 12"""

    @property
    def geqo_effort(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """tradeoff between planning time and query plan quality, default is 5"""

    @property
    def geqo_pool_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """number of individuals in the genetic population, useful values are typically 100 to 1000; default - 0 - choose based on based on geqo_effort"""

    @property
    def geqo_generations(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """the number of generations used by GEQO, useful values are in the same range as the pool size"""

    @property
    def geqo_selection_bias(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """selective pressure within the population"""

    @property
    def geqo_seed(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """initial value of the random number generator used by GEQO"""

    @property
    def pg_trgm_similarity_threshold(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def pg_trgm_word_similarity_threshold(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def pg_trgm_strict_word_similarity_threshold(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def max_standby_archive_delay(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def session_duration_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Terminate any session that exceeds the designated timeout, specified in milliseconds. If a timeout is not specified, the default session timeout is set to 12 hours. To disable it, specify a value of 0."""

    @property
    def log_replication_commands(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_autovacuum_min_duration(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds. The default is 1000 (1 sec)."""

    def __init__(
        self,
        *,
        max_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        shared_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        temp_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_prepared_transactions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        work_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        maintenance_work_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        autovacuum_work_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        temp_file_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        vacuum_cost_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        vacuum_cost_page_hit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        vacuum_cost_page_miss: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        vacuum_cost_page_dirty: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        vacuum_cost_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        bgwriter_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        bgwriter_lru_maxpages: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        bgwriter_lru_multiplier: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        bgwriter_flush_after: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        backend_flush_after: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        old_snapshot_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        wal_level: global___PostgresqlConfig11_1C.WalLevel.ValueType = ...,
        synchronous_commit: global___PostgresqlConfig11_1C.SynchronousCommit.ValueType = ...,
        checkpoint_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        checkpoint_completion_target: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        checkpoint_flush_after: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_wal_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        min_wal_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_standby_streaming_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        default_statistics_target: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        constraint_exclusion: global___PostgresqlConfig11_1C.ConstraintExclusion.ValueType = ...,
        cursor_tuple_fraction: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        from_collapse_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        join_collapse_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        force_parallel_mode: global___PostgresqlConfig11_1C.ForceParallelMode.ValueType = ...,
        client_min_messages: global___PostgresqlConfig11_1C.LogLevel.ValueType = ...,
        log_min_messages: global___PostgresqlConfig11_1C.LogLevel.ValueType = ...,
        log_min_error_statement: global___PostgresqlConfig11_1C.LogLevel.ValueType = ...,
        log_min_duration_statement: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_checkpoints: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_connections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_disconnections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_duration: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_error_verbosity: global___PostgresqlConfig11_1C.LogErrorVerbosity.ValueType = ...,
        log_lock_waits: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_statement: global___PostgresqlConfig11_1C.LogStatement.ValueType = ...,
        log_temp_files: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        search_path: builtins.str = ...,
        row_security: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        default_transaction_isolation: global___PostgresqlConfig11_1C.TransactionIsolation.ValueType = ...,
        statement_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        lock_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        idle_in_transaction_session_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        bytea_output: global___PostgresqlConfig11_1C.ByteaOutput.ValueType = ...,
        xmlbinary: global___PostgresqlConfig11_1C.XmlBinary.ValueType = ...,
        xmloption: global___PostgresqlConfig11_1C.XmlOption.ValueType = ...,
        gin_pending_list_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        deadlock_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_locks_per_transaction: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_pred_locks_per_transaction: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        array_nulls: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        backslash_quote: global___PostgresqlConfig11_1C.BackslashQuote.ValueType = ...,
        default_with_oids: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        escape_string_warning: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        lo_compat_privileges: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        operator_precedence_warning: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        quote_all_identifiers: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        standard_conforming_strings: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        synchronize_seqscans: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        transform_null_equals: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        exit_on_error: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        seq_page_cost: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        random_page_cost: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        autovacuum_max_workers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        autovacuum_vacuum_cost_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        autovacuum_vacuum_cost_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        autovacuum_naptime: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        archive_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        track_activity_query_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        online_analyze_enable: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_bitmapscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_hashagg: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_hashjoin: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_indexscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_indexonlyscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_material: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_mergejoin: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_nestloop: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_seqscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_sort: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_tidscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_worker_processes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_parallel_workers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_parallel_workers_per_gather: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        autovacuum_vacuum_scale_factor: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        autovacuum_analyze_scale_factor: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        default_transaction_read_only: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        timezone: builtins.str = ...,
        enable_parallel_append: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_parallel_hash: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_partition_pruning: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_partitionwise_aggregate: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_partitionwise_join: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        jit: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_parallel_maintenance_workers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        parallel_leader_participation: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        vacuum_cleanup_index_scale_factor: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        effective_io_concurrency: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        effective_cache_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        shared_preload_libraries: collections.abc.Iterable[global___PostgresqlConfig11_1C.SharedPreloadLibraries.ValueType] | None = ...,
        auto_explain_log_min_duration: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        auto_explain_log_analyze: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        auto_explain_log_buffers: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        auto_explain_log_timing: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        auto_explain_log_triggers: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        auto_explain_log_verbose: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        auto_explain_log_nested_statements: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        auto_explain_sample_rate: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        pg_hint_plan_enable_hint: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        pg_hint_plan_enable_hint_table: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        pg_hint_plan_debug_print: global___PostgresqlConfig11_1C.PgHintPlanDebugPrint.ValueType = ...,
        pg_hint_plan_message_level: global___PostgresqlConfig11_1C.LogLevel.ValueType = ...,
        pg_qualstats_enabled: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        pg_qualstats_track_constants: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        pg_qualstats_max: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        pg_qualstats_resolve_oids: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        pg_qualstats_sample_rate: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        plantuner_fix_empty_table: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_stack_depth: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        geqo: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        geqo_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        geqo_effort: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        geqo_pool_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        geqo_generations: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        geqo_selection_bias: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        geqo_seed: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        pg_trgm_similarity_threshold: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        pg_trgm_word_similarity_threshold: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        pg_trgm_strict_word_similarity_threshold: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        max_standby_archive_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        session_duration_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_replication_commands: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_autovacuum_min_duration: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        password_encryption: global___PostgresqlConfig11_1C.PasswordEncryption.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["archive_timeout", b"archive_timeout", "array_nulls", b"array_nulls", "auto_explain_log_analyze", b"auto_explain_log_analyze", "auto_explain_log_buffers", b"auto_explain_log_buffers", "auto_explain_log_min_duration", b"auto_explain_log_min_duration", "auto_explain_log_nested_statements", b"auto_explain_log_nested_statements", "auto_explain_log_timing", b"auto_explain_log_timing", "auto_explain_log_triggers", b"auto_explain_log_triggers", "auto_explain_log_verbose", b"auto_explain_log_verbose", "auto_explain_sample_rate", b"auto_explain_sample_rate", "autovacuum_analyze_scale_factor", b"autovacuum_analyze_scale_factor", "autovacuum_max_workers", b"autovacuum_max_workers", "autovacuum_naptime", b"autovacuum_naptime", "autovacuum_vacuum_cost_delay", b"autovacuum_vacuum_cost_delay", "autovacuum_vacuum_cost_limit", b"autovacuum_vacuum_cost_limit", "autovacuum_vacuum_scale_factor", b"autovacuum_vacuum_scale_factor", "autovacuum_work_mem", b"autovacuum_work_mem", "backend_flush_after", b"backend_flush_after", "bgwriter_delay", b"bgwriter_delay", "bgwriter_flush_after", b"bgwriter_flush_after", "bgwriter_lru_maxpages", b"bgwriter_lru_maxpages", "bgwriter_lru_multiplier", b"bgwriter_lru_multiplier", "checkpoint_completion_target", b"checkpoint_completion_target", "checkpoint_flush_after", b"checkpoint_flush_after", "checkpoint_timeout", b"checkpoint_timeout", "cursor_tuple_fraction", b"cursor_tuple_fraction", "deadlock_timeout", b"deadlock_timeout", "default_statistics_target", b"default_statistics_target", "default_transaction_read_only", b"default_transaction_read_only", "default_with_oids", b"default_with_oids", "effective_cache_size", b"effective_cache_size", "effective_io_concurrency", b"effective_io_concurrency", "enable_bitmapscan", b"enable_bitmapscan", "enable_hashagg", b"enable_hashagg", "enable_hashjoin", b"enable_hashjoin", "enable_indexonlyscan", b"enable_indexonlyscan", "enable_indexscan", b"enable_indexscan", "enable_material", b"enable_material", "enable_mergejoin", b"enable_mergejoin", "enable_nestloop", b"enable_nestloop", "enable_parallel_append", b"enable_parallel_append", "enable_parallel_hash", b"enable_parallel_hash", "enable_partition_pruning", b"enable_partition_pruning", "enable_partitionwise_aggregate", b"enable_partitionwise_aggregate", "enable_partitionwise_join", b"enable_partitionwise_join", "enable_seqscan", b"enable_seqscan", "enable_sort", b"enable_sort", "enable_tidscan", b"enable_tidscan", "escape_string_warning", b"escape_string_warning", "exit_on_error", b"exit_on_error", "from_collapse_limit", b"from_collapse_limit", "geqo", b"geqo", "geqo_effort", b"geqo_effort", "geqo_generations", b"geqo_generations", "geqo_pool_size", b"geqo_pool_size", "geqo_seed", b"geqo_seed", "geqo_selection_bias", b"geqo_selection_bias", "geqo_threshold", b"geqo_threshold", "gin_pending_list_limit", b"gin_pending_list_limit", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "jit", b"jit", "join_collapse_limit", b"join_collapse_limit", "lo_compat_privileges", b"lo_compat_privileges", "lock_timeout", b"lock_timeout", "log_autovacuum_min_duration", b"log_autovacuum_min_duration", "log_checkpoints", b"log_checkpoints", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_duration", b"log_duration", "log_lock_waits", b"log_lock_waits", "log_min_duration_statement", b"log_min_duration_statement", "log_replication_commands", b"log_replication_commands", "log_temp_files", b"log_temp_files", "maintenance_work_mem", b"maintenance_work_mem", "max_connections", b"max_connections", "max_locks_per_transaction", b"max_locks_per_transaction", "max_parallel_maintenance_workers", b"max_parallel_maintenance_workers", "max_parallel_workers", b"max_parallel_workers", "max_parallel_workers_per_gather", b"max_parallel_workers_per_gather", "max_pred_locks_per_transaction", b"max_pred_locks_per_transaction", "max_prepared_transactions", b"max_prepared_transactions", "max_stack_depth", b"max_stack_depth", "max_standby_archive_delay", b"max_standby_archive_delay", "max_standby_streaming_delay", b"max_standby_streaming_delay", "max_wal_size", b"max_wal_size", "max_worker_processes", b"max_worker_processes", "min_wal_size", b"min_wal_size", "old_snapshot_threshold", b"old_snapshot_threshold", "online_analyze_enable", b"online_analyze_enable", "operator_precedence_warning", b"operator_precedence_warning", "parallel_leader_participation", b"parallel_leader_participation", "pg_hint_plan_enable_hint", b"pg_hint_plan_enable_hint", "pg_hint_plan_enable_hint_table", b"pg_hint_plan_enable_hint_table", "pg_qualstats_enabled", b"pg_qualstats_enabled", "pg_qualstats_max", b"pg_qualstats_max", "pg_qualstats_resolve_oids", b"pg_qualstats_resolve_oids", "pg_qualstats_sample_rate", b"pg_qualstats_sample_rate", "pg_qualstats_track_constants", b"pg_qualstats_track_constants", "pg_trgm_similarity_threshold", b"pg_trgm_similarity_threshold", "pg_trgm_strict_word_similarity_threshold", b"pg_trgm_strict_word_similarity_threshold", "pg_trgm_word_similarity_threshold", b"pg_trgm_word_similarity_threshold", "plantuner_fix_empty_table", b"plantuner_fix_empty_table", "quote_all_identifiers", b"quote_all_identifiers", "random_page_cost", b"random_page_cost", "row_security", b"row_security", "seq_page_cost", b"seq_page_cost", "session_duration_timeout", b"session_duration_timeout", "shared_buffers", b"shared_buffers", "standard_conforming_strings", b"standard_conforming_strings", "statement_timeout", b"statement_timeout", "synchronize_seqscans", b"synchronize_seqscans", "temp_buffers", b"temp_buffers", "temp_file_limit", b"temp_file_limit", "track_activity_query_size", b"track_activity_query_size", "transform_null_equals", b"transform_null_equals", "vacuum_cleanup_index_scale_factor", b"vacuum_cleanup_index_scale_factor", "vacuum_cost_delay", b"vacuum_cost_delay", "vacuum_cost_limit", b"vacuum_cost_limit", "vacuum_cost_page_dirty", b"vacuum_cost_page_dirty", "vacuum_cost_page_hit", b"vacuum_cost_page_hit", "vacuum_cost_page_miss", b"vacuum_cost_page_miss", "work_mem", b"work_mem"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["archive_timeout", b"archive_timeout", "array_nulls", b"array_nulls", "auto_explain_log_analyze", b"auto_explain_log_analyze", "auto_explain_log_buffers", b"auto_explain_log_buffers", "auto_explain_log_min_duration", b"auto_explain_log_min_duration", "auto_explain_log_nested_statements", b"auto_explain_log_nested_statements", "auto_explain_log_timing", b"auto_explain_log_timing", "auto_explain_log_triggers", b"auto_explain_log_triggers", "auto_explain_log_verbose", b"auto_explain_log_verbose", "auto_explain_sample_rate", b"auto_explain_sample_rate", "autovacuum_analyze_scale_factor", b"autovacuum_analyze_scale_factor", "autovacuum_max_workers", b"autovacuum_max_workers", "autovacuum_naptime", b"autovacuum_naptime", "autovacuum_vacuum_cost_delay", b"autovacuum_vacuum_cost_delay", "autovacuum_vacuum_cost_limit", b"autovacuum_vacuum_cost_limit", "autovacuum_vacuum_scale_factor", b"autovacuum_vacuum_scale_factor", "autovacuum_work_mem", b"autovacuum_work_mem", "backend_flush_after", b"backend_flush_after", "backslash_quote", b"backslash_quote", "bgwriter_delay", b"bgwriter_delay", "bgwriter_flush_after", b"bgwriter_flush_after", "bgwriter_lru_maxpages", b"bgwriter_lru_maxpages", "bgwriter_lru_multiplier", b"bgwriter_lru_multiplier", "bytea_output", b"bytea_output", "checkpoint_completion_target", b"checkpoint_completion_target", "checkpoint_flush_after", b"checkpoint_flush_after", "checkpoint_timeout", b"checkpoint_timeout", "client_min_messages", b"client_min_messages", "constraint_exclusion", b"constraint_exclusion", "cursor_tuple_fraction", b"cursor_tuple_fraction", "deadlock_timeout", b"deadlock_timeout", "default_statistics_target", b"default_statistics_target", "default_transaction_isolation", b"default_transaction_isolation", "default_transaction_read_only", b"default_transaction_read_only", "default_with_oids", b"default_with_oids", "effective_cache_size", b"effective_cache_size", "effective_io_concurrency", b"effective_io_concurrency", "enable_bitmapscan", b"enable_bitmapscan", "enable_hashagg", b"enable_hashagg", "enable_hashjoin", b"enable_hashjoin", "enable_indexonlyscan", b"enable_indexonlyscan", "enable_indexscan", b"enable_indexscan", "enable_material", b"enable_material", "enable_mergejoin", b"enable_mergejoin", "enable_nestloop", b"enable_nestloop", "enable_parallel_append", b"enable_parallel_append", "enable_parallel_hash", b"enable_parallel_hash", "enable_partition_pruning", b"enable_partition_pruning", "enable_partitionwise_aggregate", b"enable_partitionwise_aggregate", "enable_partitionwise_join", b"enable_partitionwise_join", "enable_seqscan", b"enable_seqscan", "enable_sort", b"enable_sort", "enable_tidscan", b"enable_tidscan", "escape_string_warning", b"escape_string_warning", "exit_on_error", b"exit_on_error", "force_parallel_mode", b"force_parallel_mode", "from_collapse_limit", b"from_collapse_limit", "geqo", b"geqo", "geqo_effort", b"geqo_effort", "geqo_generations", b"geqo_generations", "geqo_pool_size", b"geqo_pool_size", "geqo_seed", b"geqo_seed", "geqo_selection_bias", b"geqo_selection_bias", "geqo_threshold", b"geqo_threshold", "gin_pending_list_limit", b"gin_pending_list_limit", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "jit", b"jit", "join_collapse_limit", b"join_collapse_limit", "lo_compat_privileges", b"lo_compat_privileges", "lock_timeout", b"lock_timeout", "log_autovacuum_min_duration", b"log_autovacuum_min_duration", "log_checkpoints", b"log_checkpoints", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_duration", b"log_duration", "log_error_verbosity", b"log_error_verbosity", "log_lock_waits", b"log_lock_waits", "log_min_duration_statement", b"log_min_duration_statement", "log_min_error_statement", b"log_min_error_statement", "log_min_messages", b"log_min_messages", "log_replication_commands", b"log_replication_commands", "log_statement", b"log_statement", "log_temp_files", b"log_temp_files", "maintenance_work_mem", b"maintenance_work_mem", "max_connections", b"max_connections", "max_locks_per_transaction", b"max_locks_per_transaction", "max_parallel_maintenance_workers", b"max_parallel_maintenance_workers", "max_parallel_workers", b"max_parallel_workers", "max_parallel_workers_per_gather", b"max_parallel_workers_per_gather", "max_pred_locks_per_transaction", b"max_pred_locks_per_transaction", "max_prepared_transactions", b"max_prepared_transactions", "max_stack_depth", b"max_stack_depth", "max_standby_archive_delay", b"max_standby_archive_delay", "max_standby_streaming_delay", b"max_standby_streaming_delay", "max_wal_size", b"max_wal_size", "max_worker_processes", b"max_worker_processes", "min_wal_size", b"min_wal_size", "old_snapshot_threshold", b"old_snapshot_threshold", "online_analyze_enable", b"online_analyze_enable", "operator_precedence_warning", b"operator_precedence_warning", "parallel_leader_participation", b"parallel_leader_participation", "password_encryption", b"password_encryption", "pg_hint_plan_debug_print", b"pg_hint_plan_debug_print", "pg_hint_plan_enable_hint", b"pg_hint_plan_enable_hint", "pg_hint_plan_enable_hint_table", b"pg_hint_plan_enable_hint_table", "pg_hint_plan_message_level", b"pg_hint_plan_message_level", "pg_qualstats_enabled", b"pg_qualstats_enabled", "pg_qualstats_max", b"pg_qualstats_max", "pg_qualstats_resolve_oids", b"pg_qualstats_resolve_oids", "pg_qualstats_sample_rate", b"pg_qualstats_sample_rate", "pg_qualstats_track_constants", b"pg_qualstats_track_constants", "pg_trgm_similarity_threshold", b"pg_trgm_similarity_threshold", "pg_trgm_strict_word_similarity_threshold", b"pg_trgm_strict_word_similarity_threshold", "pg_trgm_word_similarity_threshold", b"pg_trgm_word_similarity_threshold", "plantuner_fix_empty_table", b"plantuner_fix_empty_table", "quote_all_identifiers", b"quote_all_identifiers", "random_page_cost", b"random_page_cost", "row_security", b"row_security", "search_path", b"search_path", "seq_page_cost", b"seq_page_cost", "session_duration_timeout", b"session_duration_timeout", "shared_buffers", b"shared_buffers", "shared_preload_libraries", b"shared_preload_libraries", "standard_conforming_strings", b"standard_conforming_strings", "statement_timeout", b"statement_timeout", "synchronize_seqscans", b"synchronize_seqscans", "synchronous_commit", b"synchronous_commit", "temp_buffers", b"temp_buffers", "temp_file_limit", b"temp_file_limit", "timezone", b"timezone", "track_activity_query_size", b"track_activity_query_size", "transform_null_equals", b"transform_null_equals", "vacuum_cleanup_index_scale_factor", b"vacuum_cleanup_index_scale_factor", "vacuum_cost_delay", b"vacuum_cost_delay", "vacuum_cost_limit", b"vacuum_cost_limit", "vacuum_cost_page_dirty", b"vacuum_cost_page_dirty", "vacuum_cost_page_hit", b"vacuum_cost_page_hit", "vacuum_cost_page_miss", b"vacuum_cost_page_miss", "wal_level", b"wal_level", "work_mem", b"work_mem", "xmlbinary", b"xmlbinary", "xmloption", b"xmloption"]) -> None: ...

global___PostgresqlConfig11_1C = PostgresqlConfig11_1C

@typing.final
class PostgresqlConfigSet11_1C(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___PostgresqlConfig11_1C:
        """Effective settings for a PostgreSQL 11 1C cluster (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___PostgresqlConfig11_1C:
        """User-defined settings for a PostgreSQL 11 1C cluster."""

    @property
    def default_config(self) -> global___PostgresqlConfig11_1C:
        """Default configuration for a PostgreSQL 11 1C cluster."""

    def __init__(
        self,
        *,
        effective_config: global___PostgresqlConfig11_1C | None = ...,
        user_config: global___PostgresqlConfig11_1C | None = ...,
        default_config: global___PostgresqlConfig11_1C | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___PostgresqlConfigSet11_1C = PostgresqlConfigSet11_1C



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.video.v1.playlist_pb2
import yandex.cloud.video.v1.playlist_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class PlaylistServiceStub:
    """Playlist management service.
    Provides methods for creating, retrieving, updating, and deleting playlists,
    which are collections of videos or episodes that can be played sequentially.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistRequest,
        yandex.cloud.video.v1.playlist_pb2.Playlist,
    ]
    """Retrieves detailed information about a specific playlist by its ID.
    Returns all playlist metadata, items, and related information.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.ListPlaylistsRequest,
        yandex.cloud.video.v1.playlist_service_pb2.ListPlaylistsResponse,
    ]
    """Lists all playlists in a specific channel with pagination support.
    Results can be filtered and sorted using the provided parameters.
    """

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.CreatePlaylistRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new playlist in the specified channel with the provided items.
    Playlists can contain videos, episodes, or a mix of both content types.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.UpdatePlaylistRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates an existing playlist's metadata and items.
    Only fields specified in the field_mask will be updated.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.DeletePlaylistRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a specific playlist by its ID.
    This removes the playlist but does not affect the videos or episodes it contains.
    """

    BatchDelete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.BatchDeletePlaylistsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes multiple playlists in a specific channel in a single request.
    This is more efficient than making multiple Delete requests when removing several playlists.
    """

    GetPlayerURL: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistPlayerURLRequest,
        yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistPlayerURLResponse,
    ]
    """Generates a player URL for watching the playlist.
    The URL can include player parameters such as autoplay, mute, and visibility of interface controls.
    """

class PlaylistServiceAsyncStub:
    """Playlist management service.
    Provides methods for creating, retrieving, updating, and deleting playlists,
    which are collections of videos or episodes that can be played sequentially.
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistRequest,
        yandex.cloud.video.v1.playlist_pb2.Playlist,
    ]
    """Retrieves detailed information about a specific playlist by its ID.
    Returns all playlist metadata, items, and related information.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.ListPlaylistsRequest,
        yandex.cloud.video.v1.playlist_service_pb2.ListPlaylistsResponse,
    ]
    """Lists all playlists in a specific channel with pagination support.
    Results can be filtered and sorted using the provided parameters.
    """

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.CreatePlaylistRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new playlist in the specified channel with the provided items.
    Playlists can contain videos, episodes, or a mix of both content types.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.UpdatePlaylistRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates an existing playlist's metadata and items.
    Only fields specified in the field_mask will be updated.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.DeletePlaylistRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a specific playlist by its ID.
    This removes the playlist but does not affect the videos or episodes it contains.
    """

    BatchDelete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.BatchDeletePlaylistsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes multiple playlists in a specific channel in a single request.
    This is more efficient than making multiple Delete requests when removing several playlists.
    """

    GetPlayerURL: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistPlayerURLRequest,
        yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistPlayerURLResponse,
    ]
    """Generates a player URL for watching the playlist.
    The URL can include player parameters such as autoplay, mute, and visibility of interface controls.
    """

class PlaylistServiceServicer(metaclass=abc.ABCMeta):
    """Playlist management service.
    Provides methods for creating, retrieving, updating, and deleting playlists,
    which are collections of videos or episodes that can be played sequentially.
    """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.playlist_pb2.Playlist, collections.abc.Awaitable[yandex.cloud.video.v1.playlist_pb2.Playlist]]:
        """Retrieves detailed information about a specific playlist by its ID.
        Returns all playlist metadata, items, and related information.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.video.v1.playlist_service_pb2.ListPlaylistsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.playlist_service_pb2.ListPlaylistsResponse, collections.abc.Awaitable[yandex.cloud.video.v1.playlist_service_pb2.ListPlaylistsResponse]]:
        """Lists all playlists in a specific channel with pagination support.
        Results can be filtered and sorted using the provided parameters.
        """

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.video.v1.playlist_service_pb2.CreatePlaylistRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new playlist in the specified channel with the provided items.
        Playlists can contain videos, episodes, or a mix of both content types.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.video.v1.playlist_service_pb2.UpdatePlaylistRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates an existing playlist's metadata and items.
        Only fields specified in the field_mask will be updated.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.video.v1.playlist_service_pb2.DeletePlaylistRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes a specific playlist by its ID.
        This removes the playlist but does not affect the videos or episodes it contains.
        """

    @abc.abstractmethod
    def BatchDelete(
        self,
        request: yandex.cloud.video.v1.playlist_service_pb2.BatchDeletePlaylistsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes multiple playlists in a specific channel in a single request.
        This is more efficient than making multiple Delete requests when removing several playlists.
        """

    @abc.abstractmethod
    def GetPlayerURL(
        self,
        request: yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistPlayerURLRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistPlayerURLResponse, collections.abc.Awaitable[yandex.cloud.video.v1.playlist_service_pb2.GetPlaylistPlayerURLResponse]]:
        """Generates a player URL for watching the playlist.
        The URL can include player parameters such as autoplay, mute, and visibility of interface controls.
        """

def add_PlaylistServiceServicer_to_server(servicer: PlaylistServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/saml/federation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/saml/federation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9yandex/cloud/organizationmanager/v1/saml/federation.proto\x12(yandex.cloud.organizationmanager.v1.saml\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xbc\x05\n\nFederation\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x33\n\x04name\x18\x03 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x0e\x63ookie_max_age\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0b\xfa\xc7\x31\x07\x31\x30m-12h\x12$\n\x1c\x61uto_create_account_on_login\x18\x07 \x01(\x08\x12\x1e\n\x06issuer\x18\x08 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12J\n\x0bsso_binding\x18\t \x01(\x0e\x32\x35.yandex.cloud.organizationmanager.v1.saml.BindingType\x12\x1f\n\x07sso_url\x18\n \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12_\n\x11security_settings\x18\x0b \x01(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.saml.FederationSecuritySettings\x12!\n\x19\x63\x61se_insensitive_name_ids\x18\x0c \x01(\x08\x12P\n\x06labels\x18\r \x03(\x0b\x32@.yandex.cloud.organizationmanager.v1.saml.Federation.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"O\n\x1a\x46\x65\x64\x65rationSecuritySettings\x12\x1c\n\x14\x65ncrypted_assertions\x18\x01 \x01(\x08\x12\x13\n\x0b\x66orce_authn\x18\x02 \x01(\x08\"\x95\x03\n\x06\x44omain\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12G\n\x06status\x18\x02 \x01(\x0e\x32\x37.yandex.cloud.organizationmanager.v1.saml.Domain.Status\x12\x13\n\x0bstatus_code\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0cvalidated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12M\n\nchallenges\x18\x06 \x03(\x0b\x32\x39.yandex.cloud.organizationmanager.v1.saml.DomainChallenge\"l\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10NEED_TO_VALIDATE\x10\x01\x12\x0e\n\nVALIDATING\x10\x02\x12\t\n\x05VALID\x10\x03\x12\x0b\n\x07INVALID\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05\"\xa8\x05\n\x0f\x44omainChallenge\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12L\n\x04type\x18\x03 \x01(\x0e\x32>.yandex.cloud.organizationmanager.v1.saml.DomainChallenge.Type\x12P\n\x06status\x18\x04 \x01(\x0e\x32@.yandex.cloud.organizationmanager.v1.saml.DomainChallenge.Status\x12\\\n\rdns_challenge\x18\x05 \x01(\x0b\x32\x43.yandex.cloud.organizationmanager.v1.saml.DomainChallenge.DnsRecordH\x00\x1a\xa7\x01\n\tDnsRecord\x12\x0c\n\x04name\x18\x01 \x01(\t\x12V\n\x04type\x18\x02 \x01(\x0e\x32H.yandex.cloud.organizationmanager.v1.saml.DomainChallenge.DnsRecord.Type\x12\r\n\x05value\x18\x03 \x01(\t\"%\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03TXT\x10\x01\")\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x44NS_TXT\x10\x01\"U\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\t\n\x05VALID\x10\x03\x12\x0b\n\x07INVALID\x10\x04\x42\x0b\n\tchallenge*Q\n\x0b\x42indingType\x12\x1c\n\x18\x42INDING_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04POST\x10\x01\x12\x0c\n\x08REDIRECT\x10\x02\x12\x0c\n\x08\x41RTIFACT\x10\x03\x42\x81\x01\n,yandex.cloud.api.organizationmanager.v1.samlZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/saml;samlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.saml.federation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,yandex.cloud.api.organizationmanager.v1.samlZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/saml;saml'
  _globals['_FEDERATION_LABELSENTRY']._loaded_options = None
  _globals['_FEDERATION_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_FEDERATION'].fields_by_name['id']._loaded_options = None
  _globals['_FEDERATION'].fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_FEDERATION'].fields_by_name['name']._loaded_options = None
  _globals['_FEDERATION'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_FEDERATION'].fields_by_name['description']._loaded_options = None
  _globals['_FEDERATION'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_FEDERATION'].fields_by_name['cookie_max_age']._loaded_options = None
  _globals['_FEDERATION'].fields_by_name['cookie_max_age']._serialized_options = b'\372\3071\00710m-12h'
  _globals['_FEDERATION'].fields_by_name['issuer']._loaded_options = None
  _globals['_FEDERATION'].fields_by_name['issuer']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_FEDERATION'].fields_by_name['sso_url']._loaded_options = None
  _globals['_FEDERATION'].fields_by_name['sso_url']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_BINDINGTYPE']._serialized_start=2074
  _globals['_BINDINGTYPE']._serialized_end=2155
  _globals['_FEDERATION']._serialized_start=200
  _globals['_FEDERATION']._serialized_end=900
  _globals['_FEDERATION_LABELSENTRY']._serialized_start=855
  _globals['_FEDERATION_LABELSENTRY']._serialized_end=900
  _globals['_FEDERATIONSECURITYSETTINGS']._serialized_start=902
  _globals['_FEDERATIONSECURITYSETTINGS']._serialized_end=981
  _globals['_DOMAIN']._serialized_start=984
  _globals['_DOMAIN']._serialized_end=1389
  _globals['_DOMAIN_STATUS']._serialized_start=1281
  _globals['_DOMAIN_STATUS']._serialized_end=1389
  _globals['_DOMAINCHALLENGE']._serialized_start=1392
  _globals['_DOMAINCHALLENGE']._serialized_end=2072
  _globals['_DOMAINCHALLENGE_DNSRECORD']._serialized_start=1762
  _globals['_DOMAINCHALLENGE_DNSRECORD']._serialized_end=1929
  _globals['_DOMAINCHALLENGE_DNSRECORD_TYPE']._serialized_start=1892
  _globals['_DOMAINCHALLENGE_DNSRECORD_TYPE']._serialized_end=1929
  _globals['_DOMAINCHALLENGE_TYPE']._serialized_start=1931
  _globals['_DOMAINCHALLENGE_TYPE']._serialized_end=1972
  _globals['_DOMAINCHALLENGE_STATUS']._serialized_start=1974
  _globals['_DOMAINCHALLENGE_STATUS']._serialized_end=2059
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import google.type.timeofday_pb2
import sys
import typing
import yandex.cloud.mdb.spqr.v1.config_pb2
import yandex.cloud.mdb.spqr.v1.maintenance_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Cluster(google.protobuf.message.Message):
    """A managed SPQR cluster. For more information, see the [documentation](/docs/managed-spqr/concepts)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Environment:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EnvironmentEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Environment.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ENVIRONMENT_UNSPECIFIED: Cluster._Environment.ValueType  # 0
        PRODUCTION: Cluster._Environment.ValueType  # 1
        """Stable environment with a conservative update policy: only hotfixes
        are applied during regular maintenance.
        """
        PRESTABLE: Cluster._Environment.ValueType  # 2
        """Environment with more aggressive update policy: new versions
        are rolled out irrespective of backward compatibility.
        """

    class Environment(_Environment, metaclass=_EnvironmentEnumTypeWrapper):
        """Deployment environment."""

    ENVIRONMENT_UNSPECIFIED: Cluster.Environment.ValueType  # 0
    PRODUCTION: Cluster.Environment.ValueType  # 1
    """Stable environment with a conservative update policy: only hotfixes
    are applied during regular maintenance.
    """
    PRESTABLE: Cluster.Environment.ValueType  # 2
    """Environment with more aggressive update policy: new versions
    are rolled out irrespective of backward compatibility.
    """

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Cluster._Health.ValueType  # 0
        """State of the cluster is unknown ([Host.health] for every host in the cluster is UNKNOWN)."""
        ALIVE: Cluster._Health.ValueType  # 1
        """Cluster is alive and well ([Host.health] for every host in the cluster is ALIVE)."""
        DEAD: Cluster._Health.ValueType  # 2
        """Cluster is inoperable ([Host.health] for every host in the cluster is DEAD)."""
        DEGRADED: Cluster._Health.ValueType  # 3
        """Cluster is working below capacity ([Host.health] for at least one host in the cluster is not ALIVE)."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Cluster.Health.ValueType  # 0
    """State of the cluster is unknown ([Host.health] for every host in the cluster is UNKNOWN)."""
    ALIVE: Cluster.Health.ValueType  # 1
    """Cluster is alive and well ([Host.health] for every host in the cluster is ALIVE)."""
    DEAD: Cluster.Health.ValueType  # 2
    """Cluster is inoperable ([Host.health] for every host in the cluster is DEAD)."""
    DEGRADED: Cluster.Health.ValueType  # 3
    """Cluster is working below capacity ([Host.health] for at least one host in the cluster is not ALIVE)."""

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        """Cluster state is unknown."""
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running normally."""
        ERROR: Cluster._Status.ValueType  # 3
        """Cluster encountered a problem and cannot operate."""
        UPDATING: Cluster._Status.ValueType  # 4
        """Cluster is being updated."""
        STOPPING: Cluster._Status.ValueType  # 5
        """Cluster is stopping."""
        STOPPED: Cluster._Status.ValueType  # 6
        """Cluster stopped."""
        STARTING: Cluster._Status.ValueType  # 7
        """Cluster is starting."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    """Cluster state is unknown."""
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running normally."""
    ERROR: Cluster.Status.ValueType  # 3
    """Cluster encountered a problem and cannot operate."""
    UPDATING: Cluster.Status.ValueType  # 4
    """Cluster is being updated."""
    STOPPING: Cluster.Status.ValueType  # 5
    """Cluster is stopping."""
    STOPPED: Cluster.Status.ValueType  # 6
    """Cluster stopped."""
    STARTING: Cluster.Status.ValueType  # 7
    """Cluster is starting."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    MONITORING_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PLANNED_OPERATION_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the SPQR cluster.
    This ID is assigned by MDB at creation time.
    """
    folder_id: builtins.str
    """ID of the folder that the SPQR cluster belongs to."""
    name: builtins.str
    """Name of the SPQR cluster.
    The name is unique within the folder. 1-63 characters long.
    """
    description: builtins.str
    """Description of the SPQR cluster. 0-256 characters long."""
    environment: global___Cluster.Environment.ValueType
    """Deployment environment of the SPQR cluster."""
    network_id: builtins.str
    """ID of the network that the cluster belongs to."""
    health: global___Cluster.Health.ValueType
    """Aggregated cluster health."""
    status: global___Cluster.Status.ValueType
    """Current state of the cluster."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the SPQR cluster as `` key:value `` pairs. Maximum 64 per resource."""

    @property
    def monitoring(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Monitoring]:
        """Description of monitoring systems relevant to the SPQR cluster."""

    @property
    def config(self) -> global___ClusterConfig:
        """Configuration of the SPQR cluster."""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.spqr.v1.maintenance_pb2.MaintenanceWindow:
        """Maintenance window for the cluster."""

    @property
    def planned_operation(self) -> yandex.cloud.mdb.spqr.v1.maintenance_pb2.MaintenanceOperation:
        """Planned maintenance operation to be started for the cluster within the nearest [maintenance_window]."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        environment: global___Cluster.Environment.ValueType = ...,
        monitoring: collections.abc.Iterable[global___Monitoring] | None = ...,
        config: global___ClusterConfig | None = ...,
        network_id: builtins.str = ...,
        health: global___Cluster.Health.ValueType = ...,
        status: global___Cluster.Status.ValueType = ...,
        maintenance_window: yandex.cloud.mdb.spqr.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        planned_operation: yandex.cloud.mdb.spqr.v1.maintenance_pb2.MaintenanceOperation | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "maintenance_window", b"maintenance_window", "planned_operation", b"planned_operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "environment", b"environment", "folder_id", b"folder_id", "health", b"health", "id", b"id", "labels", b"labels", "maintenance_window", b"maintenance_window", "monitoring", b"monitoring", "name", b"name", "network_id", b"network_id", "planned_operation", b"planned_operation", "security_group_ids", b"security_group_ids", "status", b"status"]) -> None: ...

global___Cluster = Cluster

@typing.final
class Monitoring(google.protobuf.message.Message):
    """Monitoring system."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the monitoring system."""
    description: builtins.str
    """Description of the monitoring system."""
    link: builtins.str
    """Link to the monitoring system charts for the SPQR cluster."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "link", b"link", "name", b"name"]) -> None: ...

global___Monitoring = Monitoring

@typing.final
class ClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPQR_CONFIG_FIELD_NUMBER: builtins.int
    BACKUP_WINDOW_START_FIELD_NUMBER: builtins.int
    BACKUP_RETAIN_PERIOD_DAYS_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    SOX_AUDIT_FIELD_NUMBER: builtins.int
    @property
    def spqr_config(self) -> yandex.cloud.mdb.spqr.v1.config_pb2.SPQRConfig:
        """Configuration for SPQR servers in the cluster."""

    @property
    def backup_window_start(self) -> google.type.timeofday_pb2.TimeOfDay:
        """Time to start the daily backup, in the UTC timezone."""

    @property
    def backup_retain_period_days(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Retain period of automatically created backup in days"""

    @property
    def access(self) -> global___Access:
        """Access policy to DB"""

    @property
    def sox_audit(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        spqr_config: yandex.cloud.mdb.spqr.v1.config_pb2.SPQRConfig | None = ...,
        backup_window_start: google.type.timeofday_pb2.TimeOfDay | None = ...,
        backup_retain_period_days: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        access: global___Access | None = ...,
        sox_audit: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access", b"access", "backup_retain_period_days", b"backup_retain_period_days", "backup_window_start", b"backup_window_start", "sox_audit", b"sox_audit", "spqr_config", b"spqr_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access", b"access", "backup_retain_period_days", b"backup_retain_period_days", "backup_window_start", b"backup_window_start", "sox_audit", b"sox_audit", "spqr_config", b"spqr_config"]) -> None: ...

global___ClusterConfig = ClusterConfig

@typing.final
class Access(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_LENS_FIELD_NUMBER: builtins.int
    WEB_SQL_FIELD_NUMBER: builtins.int
    DATA_TRANSFER_FIELD_NUMBER: builtins.int
    SERVERLESS_FIELD_NUMBER: builtins.int
    data_lens: builtins.bool
    """Allow access for DataLens."""
    web_sql: builtins.bool
    """Allow access for Web SQL."""
    data_transfer: builtins.bool
    """Allow access for DataTransfer."""
    serverless: builtins.bool
    """Allow access for Serverless.
    NOTE: Do not propagate to public API until Serverless integration is required.
    """
    def __init__(
        self,
        *,
        data_lens: builtins.bool = ...,
        web_sql: builtins.bool = ...,
        data_transfer: builtins.bool = ...,
        serverless: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data_lens", b"data_lens", "data_transfer", b"data_transfer", "serverless", b"serverless", "web_sql", b"web_sql"]) -> None: ...

global___Access = Access



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cic/v1/common/lag_allocation_settings.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cic/v1/common/lag_allocation_settings.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.cic.v1.common import lag_info_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_common_dot_lag__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/cic/v1/common/lag_allocation_settings.proto\x12\x1ayandex.cloud.cic.v1.common\x1a)yandex/cloud/cic/v1/common/lag_info.proto\"?\n\x1cLagAllocationSettingsRequest\x12\x12\n\x08lag_size\x18\r \x01(\x03H\x00\x42\x05\n\x03lagJ\x04\x08\x0e\x10\x0f\"N\n\x15LagAllocationSettings\x12\x35\n\x08lag_info\x18\x0e \x01(\x0b\x32#.yandex.cloud.cic.v1.common.LagInfoBd\n\x1eyandex.cloud.api.cic.v1.commonZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1/common;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.common.lag_allocation_settings_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.cic.v1.commonZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1/common;cic'
  _globals['_LAGALLOCATIONSETTINGSREQUEST']._serialized_start=131
  _globals['_LAGALLOCATIONSETTINGSREQUEST']._serialized_end=194
  _globals['_LAGALLOCATIONSETTINGS']._serialized_start=196
  _globals['_LAGALLOCATIONSETTINGS']._serialized_end=274
# @@protoc_insertion_point(module_scope)
